@@ -69,52 +69,107 @@ class Exploit < Msf::Module
   # https://github.com/rapid7/metasploit-framework/wiki/How-to-write-a-check()-method
   #
   ##
-  module CheckCode
+  class CheckCode < Struct.new(:code, :message, :reason)
+    # Do customization here because we need class constants and special
+    # optional values and the block mode of Struct.new does not support that.
+    #
+    #
+    # NOTE: This class relies on the array-like interface of Struct classes to
+    # provide a backwards-compatible interface for the old CheckCode
+    # representation of `['code', 'message']`. Any change to the order or
+    # meaning of fields will need to be evaluated for how it affects the rest
+    # of the codebase.
+
+    class << self
+      def Unknown(reason = nil)
+        self.new('unknown', reason)
+      end
+
+      def Safe(reason = nil)
+        self.new('safe', reason)
+      end
+
+      def Detected(reason = nil)
+        self.new('detected', reason)
+      end
+
+      def Appears(reason = nil)
+        self.new('appears', reason)
+      end
+
+      def Vulnerable(reason = nil)
+        self.new('vulnerable', reason)
+      end
+
+      def Unsupported(reason = nil)
+        self.new('unsupported', reason)
+      end
+    end
+
+    # Deprecated, should use #===
+    #
+    # If you need to determine whether a CheckCode has the same code and
+    # message as another one, {Struct#eql?} is the way to go.
+    def ==(other)
+      self === other
+    end
+
+    # Checks to see whether the other object is also a {CheckCode} and if so,
+    # whether it shares the same code as this one.
+    def ===(other)
+      other.is_a?(self.class) && self.code == other.code
+    end
+
+    def initialize(code, reason)
+      msg = case code
+        when 'unknown';     'Cannot reliably check exploitability.'
+        when 'safe';        'The target is not exploitable.'
+        when 'detected';    'The service is running, but could not be validated.'
+        when 'appears';     'The target appears to be vulnerable.'
+        when 'vulnerable';  'The target is vulnerable.'
+        when 'unsupported'; 'This module does not support check.'
+        else
+          ''
+      end
+      super(code, "#{msg} #{reason}".strip, reason)
+    end
 
     #
     # Can't tell if the target is exploitable or not. This is recommended if the module fails to
     # retrieve enough information from the target machine, such as due to a timeout.
     #
-    Unknown     = [ 'unknown', "Cannot reliably check exploitability."]
+    Unknown     = self.Unknown()
 
     #
     # The target is safe and is therefore not exploitable. This is recommended after the check
     # fails to trigger the vulnerability, or even detect the service.
     #
-    Safe        = [ 'safe', "The target is not exploitable." ]
+    Safe        = self.Safe()
 
     #
     # The target is running the service in question, but the check fails to determine whether
     # the target is vulnerable or not.
     #
-    Detected    = [ 'detected', "The target service is running, but could not be validated." ]
+    Detected    = self.Detected()
 
     #
     # The target appears to be vulnerable. This is recommended if the vulnerability is determined
     # based on passive reconnaissance. For example: version, banner grabbing, or having the resource
     # that's known to be vulnerable.
     #
-    Appears     = [ 'appears', "The target appears to be vulnerable." ]
+    Appears     = self.Appears()
 
     #
     # The target is vulnerable. Only used if the check is able to actually take advantage of the
     # bug, and obtain hard evidence. For example: executing a command on the target machine, and
     # retrieve the output.
     #
-    Vulnerable  = [ 'vulnerable', "The target is vulnerable." ]
+    Vulnerable  = self.Vulnerable()
 
     #
     # The module does not support the check method.
     #
-    Unsupported = [ 'unsupported', "This module does not support check." ]
-
-    #
-    # Hash for looking up codes by short name
-    #
-    Codes = [Unknown, Safe, Detected, Appears, Vulnerable, Unsupported].reduce({}) do |codes, code|
-      codes[code.first] = code
-      codes
-    end.freeze
+    Unsupported = self.Unsupported()
   end
 
   #
@@ -800,30 +855,32 @@ class Exploit < Msf::Module
   end
 
   #
-  # This method returns the number of bytes that should be adjusted to the
+  # This method returns the encoded instruction(s) required to adjust the
   # stack pointer prior to executing any code.  The number of bytes to adjust
   # is indicated to the routine through the payload 'StackAdjustment'
   # attribute or through a target's payload 'StackAdjustment' attribute.
   #
   def stack_adjustment
-    if (target and target.payload_stack_adjustment)
+    if target && target.payload_stack_adjustment
       adj = target.payload_stack_adjustment
     else
       adj = payload_info['StackAdjustment']
     end
 
+    return '' unless adj
+
     # Get the architecture for the current target or use the one specific to
     # this exploit
-    arch = (target and target.arch) ? target.arch : self.arch
+    arch = (target && target.arch) ? target.arch : self.arch
 
     # Default to x86 if we can't find a list of architectures
-    if (arch and arch.empty? == false)
-      arch = arch.join(", ")
+    if arch && !arch.empty?
+      arch = [arch].flatten.join(', ')
     else
       arch = 'x86'
     end
 
-    (adj != nil) ? Rex::Arch::adjust_stack_pointer(arch, adj) || '' : ''
+    Rex::Arch::adjust_stack_pointer(arch, adj) || ''
   end
 
   #
