@@ -43,6 +43,7 @@ module Exploit::Remote::HttpClient
         OptBool.new('FingerprintCheck', [ false, 'Conduct a pre-exploit fingerprint verification', true]),
         OptString.new('DOMAIN', [ true, 'The domain to use for windows authentification', 'WORKSTATION']),
         OptInt.new('HttpClientTimeout', [false, 'HTTP connection and receive timeout']),
+        OptBool.new('HttpPartialResponses', [false, 'Return partial HTTP responses despite timeouts', false]),
         OptBool.new('HttpTrace', [false, 'Show the raw HTTP requests and responses', false])
       ], self.class
     )
@@ -161,6 +162,7 @@ module Exploit::Remote::HttpClient
     nclient.set_config(
       'vhost' => opts['vhost'] || opts['rhost'] || self.vhost(),
       'agent' => datastore['UserAgent'],
+      'partial' => opts['partial'] || datastore['HttpPartialResponses'],
       'uri_encode_mode'        => datastore['HTTP::uri_encode_mode'],
       'uri_full_url'           => datastore['HTTP::uri_full_url'],
       'pad_method_uri_count'   => datastore['HTTP::pad_method_uri_count'],
@@ -188,6 +190,7 @@ module Exploit::Remote::HttpClient
       'DigestAuthIIS'          => datastore['DigestAuthIIS']
     )
 
+    # NOTE: Please use opts['headers'] to programmatically set headers
     if datastore['HttpRawHeaders'] && File.readable?(datastore['HttpRawHeaders'])
       # Templatize with ERB
       headers = ERB.new(File.read(datastore['HttpRawHeaders'])).result(binding)
@@ -305,7 +308,7 @@ module Exploit::Remote::HttpClient
   #
   # Passes +opts+ through directly to Rex::Proto::Http::Client#request_raw.
   #
-  def send_request_raw(opts={}, timeout = 20)
+  def send_request_raw(opts={}, timeout = 20, disconnect = false)
     if datastore['HttpClientTimeout'] && datastore['HttpClientTimeout'] > 0
       actual_timeout = datastore['HttpClientTimeout']
     else
@@ -336,6 +339,8 @@ module Exploit::Remote::HttpClient
         end
       end
 
+      disconnect(c) if disconnect
+
       res
     rescue ::Errno::EPIPE, ::Timeout::Error => e
       print_line(e.message) if datastore['HttpTrace']
@@ -388,7 +393,9 @@ module Exploit::Remote::HttpClient
           print_line(res.to_terminal_output)
         end
       end
+
       disconnect(c) if disconnect
+
       res
     rescue ::Errno::EPIPE, ::Timeout::Error => e
       print_line(e.message) if datastore['HttpTrace']
