@@ -433,6 +433,11 @@ module Exploit::Remote::HttpServer
   # but see {#srvhost_addr} for caveats.
   #
   def get_uri(cli=self.cli)
+    resource = get_resource
+
+    # The resource won't exist until the server is started
+    return unless resource
+
     ssl = !!(datastore["SSL"])
     proto = (ssl ? "https://" : "http://")
     if datastore['URIHOST']
@@ -457,7 +462,7 @@ module Exploit::Remote::HttpServer
       port = ":" + datastore["SRVPORT"].to_s
     end
 
-    uri = proto + host + port + get_resource
+    uri = proto + host + port + resource
 
     uri
   end
