@@ -413,7 +413,10 @@ module Exploit::Remote::RDP
     rdp_version = data[0].unpack("C")[0]
     raise RdpCommunicationError if rdp_version != 3
     length = data[2..3].unpack("n")[0]
-    raise RdpCommunicationError if data.length != length
+    if data.length < length
+      vprint_error("Got #{data.length} bytes, expected #{length}")
+      raise RdpCommunicationError
+    end
 
     data_len = data[13].unpack("C")[0]
     tag_offset = 18
