@@ -783,7 +783,7 @@ module Msf
           res.slice!(0,2) if comment_length % 2 == 1 # pad
 
           name    = Rex::Text.to_ascii(name).gsub("\x00", "")
-          s_type  = Rex::Text.to_ascii(smb_lookup_share_type(types[t])).gsub("\x00", "")
+          s_type  = smb_lookup_share_type(types[t])
           comment = Rex::Text.to_ascii(comment).gsub("\x00", "")
 
           shares << [ name, s_type, comment ]
