@@ -411,6 +411,14 @@ class Msf::Module::Platform
     Alias = "unifi"
   end
 
+  #
+  # Brocade
+  #
+  class Brocade < Msf::Module::Platform
+    Rank = 100
+    Alias = "brocade"
+  end
+
   #
   # Solaris
   #
