@@ -398,6 +398,18 @@ module Msf::Post::File
     write_file(remote, ::File.read(local))
   end
 
+  #
+  # Upload a binary and write it as an executable file +remote+ on the
+  # remote filesystem.
+  #
+  # @param remote [String] Destination file name on the remote filesystem
+  # @param data [String] Data to be uploaded
+  def upload_and_chmodx(path, data)
+    print_status "Writing '#{path}' (#{data.size} bytes) ..."
+    write_file path, data
+    chmod(path)
+  end
+
   #
   # Sets the permissions on a remote file
   #
@@ -415,6 +427,16 @@ module Msf::Post::File
     end
   end
 
+  #
+  # Read a local exploit file binary from the data directory
+  #
+  # @param path [String] Directory in the exploits folder
+  # @param path [String] Filename in the data folder
+  def exploit_data(data_directory, file)
+    file_path = ::File.join(::Msf::Config.data_directory, "exploits", data_directory, file)
+    ::File.binread(file_path)
+  end
+
   #
   # Delete remote files
   #
