@@ -170,7 +170,7 @@ class Exploit
       rhosts_range = Rex::Socket::RangeWalker.new(rhosts_opt.normalize(rhosts))
     end
     # For multiple targets exploit attempts.
-    if rhosts_range && rhosts_range.length > 1
+    if rhosts_range && rhosts_range.length.to_i > 1
       opts[:multi] = true
       rhosts_range.each do |rhost|
         nmod = mod.replicant
