@@ -314,6 +314,8 @@ class Console::CommandDispatcher::Stdapi::Sys
         print_error('Failed to spawn shell with thread impersonation. Retrying without it.')
         cmd_execute('-f', path, '-c', '-i', '-H')
       end
+    when 'android'
+      cmd_execute('-f', '/system/bin/sh', '-c', '-i')
     when 'linux', 'osx'
       if use_pty && pty_shell(sh_path)
         return true
@@ -571,7 +573,9 @@ class Console::CommandDispatcher::Stdapi::Sys
     processes.each do |p|
       if l_flag
         if f_flag
-          print_line("#{p['pid']} #{p['path']}")
+          full_path = [p['path'], p['name']].join(client.fs.file.separator)
+
+          print_line("#{p['pid']} #{full_path}")
         else
           print_line("#{p['pid']} #{p['name']}")
         end
