@@ -40,14 +40,14 @@ class MetasploitModule < Msf::Auxiliary
 
   def check_rdp
     begin
-      nsock = connect
+      rdp_connect
+      is_rdp, version_info = rdp_fingerprint
     rescue ::Errno::ETIMEDOUT, Rex::HostUnreachable, Rex::ConnectionTimeout, Rex::ConnectionRefused, ::Timeout::Error, ::EOFError
       return false, nil
+    ensure
+      rdp_disconnect
     end
 
-    is_rdp, version_info = rdp_fingerprint(nsock)
-    disconnect
-
     service_info = nil
     if is_rdp
       product_version = (version_info && version_info[:product_version]) ? version_info[:product_version] : 'N/A'
@@ -66,14 +66,14 @@ class MetasploitModule < Msf::Auxiliary
 
   def requires_nla?
     begin
-      nsock = connect
+      rdp_connect
+      is_rdp, server_selected_proto = rdp_check_protocol
     rescue ::Errno::ETIMEDOUT, Rex::HostUnreachable, Rex::ConnectionTimeout, Rex::ConnectionRefused, ::Timeout::Error, ::EOFError
       return false
+    ensure
+      rdp_disconnect
     end
 
-    is_rdp, server_selected_proto = rdp_check_protocol
-    disconnect
-
     return false unless is_rdp
     return [RDPConstants::PROTOCOL_HYBRID, RDPConstants::PROTOCOL_HYBRID_EX].include? server_selected_proto
   end
@@ -81,11 +81,13 @@ class MetasploitModule < Msf::Auxiliary
   def run_host(_ip)
     is_rdp = false
     begin
-      connect
+      rdp_connect
       is_rdp, service_info = check_rdp
     rescue Rex::ConnectionError => e
       vprint_error("Error while connecting and negotiating RDP: #{e}")
       return
+    ensure
+      rdp_disconnect
     end
     return unless is_rdp
 
