@@ -18,7 +18,7 @@ class MetasploitModule < Msf::Exploit::Remote
 
   include Msf::Exploit::Remote::HttpClient
   include Msf::Exploit::CmdStager
-  include Msf::Exploit::Deprecated
+  include Msf::Module::Deprecated
 
   moved_from 'exploit/linux/http/cisco_rv130_rmi_rce'
 
