@@ -54,12 +54,11 @@ class MetasploitModule < Msf::Exploit::Local
           ['Windows x64', { 'Arch' => ARCH_X64 }]
         ],
         'DefaultTarget' => 0,
-        'References'    => [
+        'References'    =>
           [
-            'URL', 'https://github.com/bytecode-77/slui-file-handler-hijack-privilege-escalation',
-            'URL', 'https://github.com/gushmazuko/WinBypass/blob/master/SluiHijackBypass.ps1'
-          ]
-        ],
+            ['URL', 'https://github.com/bytecode-77/slui-file-handler-hijack-privilege-escalation'],
+            ['URL', 'https://github.com/gushmazuko/WinBypass/blob/master/SluiHijackBypass.ps1']
+          ],
         'DisclosureDate' => 'Jan 15 2018'
       )
     )
