@@ -15,7 +15,7 @@ class MetasploitModule < Msf::Exploit::Local
 
   def initialize(info = {})
     super(update_info(info,
-      'Name'            => 'Windows WMI Recieve Notification Exploit',
+      'Name'            => 'Windows WMI Receive Notification Exploit',
       'Description'     => %q(
         This module exploits an uninitialized stack variable in the WMI subsystem of ntoskrnl.
         This module has been tested on vulnerable builds of Windows 7 SP0 x64 and Windows 7 SP1 x64.
